aboutsummaryrefslogtreecommitdiff
path: root/arch/x86_64/include
diff options
context:
space:
mode:
Diffstat (limited to 'arch/x86_64/include')
-rw-r--r--arch/x86_64/include/arch/memory/multiboot.hpp4
-rw-r--r--arch/x86_64/include/arch/memory/paging.hpp4
2 files changed, 4 insertions, 4 deletions
diff --git a/arch/x86_64/include/arch/memory/multiboot.hpp b/arch/x86_64/include/arch/memory/multiboot.hpp
index c070e85..9a753fa 100644
--- a/arch/x86_64/include/arch/memory/multiboot.hpp
+++ b/arch/x86_64/include/arch/memory/multiboot.hpp
@@ -180,10 +180,10 @@ namespace teachos::arch::memory
* bits that are set in the given std::bitset also have to be set in the underlyng std::bitset. Any additional bits
* that are set are not relevant.
*
* @param flags Flags that we want to compare against and check if the underlying std::bitset has the same bits set.
* @return Whether the given flags are a subset or equivalent with the underlying std::bitset
*/
- auto contains_flags(std::bitset<64U> b) const -> bool;
+ auto contains_flags(std::bitset<64U> other) const -> bool;
/**
* @brief Allows to compare the underlying std::bitset of two instances
@@ -180,10 +180,10 @@ namespace teachos::arch::memory
* that are set are not relevant.
*
- * @param flags Flags that we want to compare against and check if the underlying std::bitset has the same bits set.
+ * @param other Flags that we want to compare against and check if the underlying std::bitset has the same bits set.
* @return Whether the given flags are a subset or equivalent with the underlying std::bitset
*/
diff --git a/arch/x86_64/include/arch/memory/paging.hpp b/arch/x86_64/include/arch/memory/paging.hpp
index 0b928b0..16fa476 100644
--- a/arch/x86_64/include/arch/memory/paging.hpp
+++ b/arch/x86_64/include/arch/memory/paging.hpp
@@ -86,10 +86,10 @@ namespace teachos::arch::memory
* bits that are set in the given std::bitset also have to be set in the underlyng std::bitset. Any additional bits
* that are set are not relevant.
*
* @param flags Flags that we want to compare against and check if the underlying std::bitset has the same bits set.
* @return Whether the given flags are a subset or equivalent with the underlying std::bitset
*/
- auto contains_flags(std::bitset<64U> b) const -> bool;
+ auto contains_flags(std::bitset<64U> other) const -> bool;
private:
/**
@@ -86,10 +86,10 @@ namespace teachos::arch::memory
* that are set are not relevant.
*
- * @param flags Flags that we want to compare against and check if the underlying std::bitset has the same bits set.
+ * @param other Flags that we want to compare against and check if the underlying std::bitset has the same bits set.
* @return Whether the given flags are a subset or equivalent with the underlying std::bitset
*/